/**
 * @file   arithmetic.cc
 * @author Sebastien Fourey <http://www.greyc.ensicaen.fr/~seb>
 * @date   Tue Aug 21
 * 
 * @brief  Example that shows the usage of the Board library by 
 * illustating the arithmetic coding principle.
 * <p>Files arithm.eps, arithm.fig and arithm.svg are created in the current directory.</p>
 *
 */
/*
 * @file   arithmetic.cc
 * @author Sebastien Fourey <http://www.greyc.ensicaen.fr/~seb>
 * @date   Tue Aug 21
 * 
 * @brief  Example that shows the usage of the Board library by 
 *         illustating the arithmetic coding principle.
 *         Files arithm.eps, arithm.fig and arithm.svg are created in
 *         the current directory.
 *
 * @copyright 
 * Copyright or  or Copr. Sbastien Fourey
 * 
 * Sbastien.Fourey - http://www.greyc.ensicaen.fr/~seb
 * 
 * 
 * This source code is part of the Board project, a C++ library whose
 * purpose is to allow simple drawings in EPS, FIG or SVG files.
 * 
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms
 * 
 */
#include "Board.h"
#include <cstdlib>
#include <iostream>
#include <fstream>
#include <cmath>
using namespace std;
using namespace BoardLib;

int main( int argc, char *argv[] )
{
  Board board;
  
  if ( argc == 2 && !strcmp(argv[1],"-h") ) {
    cout << "Usage:   arithmetic [word] \n\n  Where word has letters in {a, b, c, d, e}\n\n";
    exit(0);
  }

  char the_string[1024];
  strcpy( the_string, "cccccccbb" );  
  
  if ( argc == 2 ) { 
    strcpy( the_string, argv[1] );
  }
  
  // char letters[] = "abcde";
  double proba[100] = { 0.2, 0.1, 0.6, 0.05, 0.05 };
  double lefts[100] = { 0, 0.2, 0.3, 0.9, 0.95  };
    
  char * pc = the_string;
  int h = 0;

  double thickness = 0.5 / strlen( the_string );

  board.drawRectangle( 0, 0, 1.0, 0.5 );
  board.setPenColorRGBi( 0, 0, 255 );

  double left = 0;
  //double droite = 1.0;
  double width = 1.0;
  double w = 1.0;
  double n = 1;
  char str[20];

  board.setLineWidth( 0.5 );
  board.clear( Color( 200, 200, 200 ) );
  while ( *pc ) {
    int i = *pc - 'a';
    left += width * lefts[ i ];
    width *= proba[i];

    board.setPenColorRGBi( 100, 100, 100 ); 
    w /= 2.0;
    n *= 2;
    for ( int k = 0; k < n; k++ )
      board.drawRectangle( k*w, -h * thickness, w, 0.9*thickness );

    switch ( i ) {
    case 0:  board.setPenColorRGBi( 0, 0, 255 ); break;
    case 1:  board.setPenColorRGBi( 0, 255, 0 ); break;
    case 2:  board.setPenColorRGBi( 255, 0, 0 ); break;
    case 3:  board.setPenColorRGBi( 0, 255, 255 ); break;
    case 4:  board.setPenColorRGBi( 255, 255, 0 ); break;
    }
    board.drawRectangle( left, -h * thickness, width, 0.9*thickness );

    sprintf( str, "%c", *pc );
    board.drawText( (left + width/2.0 ), -(h+0.5) * thickness, str );    
    ++h;
    ++pc;
  }

  // Draw the letters rectangles.
  for ( int k = 0; k < 5; k++ ) {
    switch ( k ) {
    case 0:  board.setPenColorRGBi( 0, 0, 255 ); break;
    case 1:  board.setPenColorRGBi( 0, 255, 0 ); break;
    case 2:  board.setPenColorRGBi( 255, 0, 0 ); break;
    case 3:  board.setPenColorRGBi( 0, 255, 255 ); break;
    case 4:  board.setPenColorRGBi( 255, 255, 0 ); break;
    }
    board.drawRectangle( lefts[k], thickness, proba[k], 0.9*thickness );      
    sprintf( str, "%c", 'a' + k  );
    board.drawText( lefts[k] + proba[k]/2.0, 0.5*thickness, str );    
  }

  board.setPenColorRGBi( 0, 0, 0 );
  board.setLineWidth(0.2);
  board.save( "arithm.eps" );
  board.save( "arithm.fig" );
  board.save( "arithm.svg" );
  exit(0);
}
