/**
 * @file   example2.cc
 * @author Sebastien Fourey <http://www.greyc.ensicaen.fr/~seb>
 * @date   Tue Aug 21
 * 
 * @brief  Sample drawing using the board library.
 * 
 */
/*
 * @file   example2.cc
 * @author Sebastien Fourey <http://www.greyc.ensicaen.fr/~seb>
 * @date   Tue Aug 21
 * 
 * @brief  Sample drawing using the board library.
 * 
 * @copyright 
 * Copyright or  or Copr. Sbastien Fourey
 * 
 * Sbastien.Fourey - http://www.greyc.ensicaen.fr/~seb
 * 
 * 
 * This source code is part of the Board project, a C++ library whose
 * purpose is to allow simple drawings in EPS, FIG or SVG files.
 * 
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms
 * 
 */
#include <cstdlib>
#include <iostream>
#include <fstream>
#include <cmath>
#include "Board.h"

using namespace BoardLib;

int main( int argc, char *argv[] )
{
  Board board;

  board.clear( Color(0,120,0) );
  board.setPenColorRGBi( 255, 0, 0 );

  std::vector<Point> points;
  for ( float x = -1.0; x < 1.0; x+=0.02 ) {
    points.push_back( Point( x, sin(x*6.28) ) );
  }
  board.setLineWidth( 0.5 );
  board.setPenColorRGBi( 0, 0, 255 );
  board.drawPolyline( points );

  board.setPenColorRGBi( 255, 0, 0 );
  for ( float x = -1.0; x < 1.1; x+=0.1 ) {
    board.setFillColorRGBi( 255, 0, 0 );
    board.setPenColorRGBi( 0, 0, 255 );
    board.drawCircle( x, 0.0, 0.1 );
  }
  board.fillCircle( 0.0, 0.0, 0.01 );
 
  board.setPenColorRGBi( 0, 0, 0 );
  board.setFillColor( Color::none );

  board.setFillColorRGBf( 1.0f, 0, 0, 0.25 ).drawEllipse( 0, -0.5, 1, 0.5 );
  
  board.setFont("Helvetica-Bold",28.0).drawText( 0, 0.5, "Hello world!" );

  board.setLineJoin( Shape::RoundJoin );
  board.setLineWidth( 8 ).setPenColor( Color::black ).setFillColorRGBi( 0, 0, 255, 50 ).drawRectangle( -1, 0, 1, 0.5 );

  board.setLineJoin( Shape::MiterJoin );
  board.setLineWidth( 10 ).setPenColor( Color::black ).drawTriangle( -0.5, -0.25, 0, 0.25, 0.5, -0.25 );
  board.setLineWidth( 0.1 ).setPenColorRGBi( 255, 0, 0 ).drawLine( -0.5, -0.25, 0.5, -0.25 );

  board.saveEPS( "draw2.eps" );
  board.saveFIG( "draw2.fig" );
  board.saveSVG( "draw2.svg" );

  exit(0);
}
